@@ -53,8 +53,8 @@ setup.jags <- function(model, monitor = stop("No monitored variables supplied"),
 	if(rjagsmethod)
 		loadandcheckrjags()
 	
-	if(class(monitor)!="character" | all(is.na(monitor))){
-		stop("Monitored variable(s) must be provided in the form of a character vector")
+	if(!inherits(monitor, "character") | all(is.na(monitor))){
+		stop("Monitored variable(s) must be provided in the form of a character vector or named list of character vectors")
 	}
 	monitor <- checkvalidmonitorname(monitor)		
 
